@@ -161,6 +161,10 @@ ce_page_validate_v (CEPage *page, NMConnection *connection, GError **error)
 			s_8021x = nm_connection_get_setting (tmp_connection, NM_TYPE_SETTING_802_1X);
 			nm_connection_add_setting (connection, NM_SETTING (g_object_ref (s_8021x)));
 
+			/* Remove the 8021x setting to prevent the clearing of secrets when the
+			 * simple-connection is destroyed.
+			 */
+			nm_connection_remove_setting (tmp_connection, NM_TYPE_SETTING_802_1X);
 			g_object_unref (tmp_connection);
 		}
 	} else {
