@@ -20,13 +20,10 @@
  * Copyright 2014 - 2015 Red Hat, Inc.
  */
 
-#include "config.h"
+#include "nm-default.h"
 
 #include <string.h>
 
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-
 #include <NetworkManager.h>
 
 #include "page-bluetooth.h"
