@@ -18,11 +18,9 @@
  * Copyright 2012 - 2014 Red Hat, Inc.
  */
 
-#include "config.h"
+#include "nm-default.h"
 
 #include <stdlib.h>
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
 
 #include "page-bond.h"
 #include "page-infiniband.h"
