@@ -53,21 +53,13 @@ finish_setup (CEPageVpn *self, gpointer unused, GError *error, gpointer user_dat
 {
 	CEPage *parent = CE_PAGE (self);
 	CEPageVpnPrivate *priv = CE_PAGE_VPN_GET_PRIVATE (self);
-	GError *vpn_error = NULL;
 
 	if (error)
 		return;
 
-	g_return_if_fail (priv->plugin != NULL);
+	g_return_if_fail (NM_IS_VPN_EDITOR_PLUGIN (priv->plugin));
+	g_return_if_fail (NM_IS_VPN_EDITOR (priv->editor));
 
-	priv->editor = nm_vpn_editor_plugin_get_editor (priv->plugin, parent->connection, &vpn_error);
-	if (!priv->editor) {
-		g_warning ("Could not load VPN user interface for service '%s': %s.",
-		           priv->service_type,
-		           (vpn_error && vpn_error->message) ? vpn_error->message : "(unknown)");
-		g_error_free (vpn_error);
-		return;
-	}
 	g_signal_connect (priv->editor, "changed", G_CALLBACK (vpn_plugin_changed_cb), self);
 
 	parent->page = GTK_WIDGET (nm_vpn_editor_get_widget (priv->editor));
@@ -90,6 +82,7 @@ ce_page_vpn_new (NMConnectionEditor *editor,
 	CEPageVpn *self;
 	CEPageVpnPrivate *priv;
 	const char *service_type;
+	GError *local = NULL;
 
 	self = CE_PAGE_VPN (ce_page_new (CE_TYPE_PAGE_VPN,
 	                                 editor,
@@ -115,7 +108,18 @@ ce_page_vpn_new (NMConnectionEditor *editor,
 
 	priv->plugin = vpn_get_plugin_by_service (service_type);
 	if (!priv->plugin) {
-		g_set_error (error, NMA_ERROR, NMA_ERROR_GENERIC, _("Could not find VPN plugin service for '%s'."), service_type);
+		g_set_error (error, NMA_ERROR, NMA_ERROR_GENERIC, _("Could not find VPN plugin for '%s'."), service_type);
+		g_object_unref (self);
+		return NULL;
+	}
+	priv->plugin = g_object_ref (priv->plugin);
+
+	priv->editor = nm_vpn_editor_plugin_get_editor (priv->plugin, CE_PAGE (self)->connection, &local);
+	if (!priv->editor) {
+		g_set_error (error, NMA_ERROR, NMA_ERROR_GENERIC,
+		             _("Could not load editor VPN plugin for '%s' (%s)."),
+		             service_type, local ? local->message : _("unknown failure"));
+		g_clear_error (&local);
 		g_object_unref (self);
 		return NULL;
 	}
@@ -132,7 +136,7 @@ ce_page_vpn_can_export (CEPageVpn *page)
 {
 	CEPageVpnPrivate *priv = CE_PAGE_VPN_GET_PRIVATE (page);
 
-	return 	(nm_vpn_editor_plugin_get_capabilities (priv->plugin) & NM_VPN_EDITOR_PLUGIN_CAPABILITY_EXPORT) != 0;
+	return (nm_vpn_editor_plugin_get_capabilities (priv->plugin) & NM_VPN_EDITOR_PLUGIN_CAPABILITY_EXPORT) != 0;
 }
 
 static gboolean
@@ -154,9 +158,14 @@ dispose (GObject *object)
 {
 	CEPageVpnPrivate *priv = CE_PAGE_VPN_GET_PRIVATE (object);
 
-	g_clear_object (&priv->editor);
+	if (priv->editor) {
+		g_signal_handlers_disconnect_by_func (priv->editor, G_CALLBACK (vpn_plugin_changed_cb), object);
+		g_clear_object (&priv->editor);
+	}
 	g_clear_pointer (&priv->service_type, g_free);
 
+	g_clear_object (&priv->plugin);
+
 	G_OBJECT_CLASS (ce_page_vpn_parent_class)->dispose (object);
 }
 
