@@ -20,7 +20,7 @@
  * (C) Copyright 2007 - 2012 Red Hat, Inc.
  */
 
-#include <config.h>
+#include "nm-default.h"
 
 #include <nm-client.h>
 
