@@ -226,8 +226,13 @@ eap_method_validate_filepicker (GtkBuilder *builder,
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, name));
 	g_assert (widget);
 	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (widget));
-	if (!filename)
-		return (item_type == TYPE_CA_CERT) ? TRUE : FALSE;
+	if (!filename) {
+		if (item_type == TYPE_CA_CERT)
+			success = TRUE;
+		else
+			g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("no file selected"));
+		goto out;
+	}
 
 	if (!g_file_test (filename, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR))
 		goto out;
@@ -393,7 +398,7 @@ default_filter_privkey (const GtkFileFilterInfo *filter_info, gpointer user_data
 	const char *extensions[] = { ".der", ".pem", ".p12", ".key", NULL };
 #endif
 	gboolean require_encrypted = !!user_data;
-	gboolean is_encrypted = TRUE;
+	gboolean is_encrypted;
 
 	if (!filter_info->filename)
 		return FALSE;
@@ -402,10 +407,12 @@ default_filter_privkey (const GtkFileFilterInfo *filter_info, gpointer user_data
 	if (!file_has_extension (filter_info->filename, extensions))
 		return FALSE;
 
+	is_encrypted = TRUE;
 	if (   !file_is_der_or_pem (filter_info->filename, TRUE, &is_encrypted)
 	    && !nm_utils_file_is_pkcs12 (filter_info->filename))
 		return FALSE;
 #elif defined (LIBNM_BUILD)
+	is_encrypted = FALSE;
 	if (!nm_utils_file_is_private_key (filter_info->filename, &is_encrypted))
 		return FALSE;
 #else
